@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2019  Winfried Bruns, Bogdan Ichim, Christof Soeger
+ * Copyright (C) 2007-2022  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * As an exception, when this program is distributed through (i) the App Store
  * by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or (iii) Google Play
@@ -64,7 +64,6 @@ namespace ConeProperty {
 enum Enum {
     // matrix valued
     START_ENUM_RANGE(FIRST_MATRIX),
-    Generators,
     ExtremeRays,
     VerticesOfPolyhedron,
     SupportHyperplanes,
@@ -81,6 +80,7 @@ enum Enum {
     END_ENUM_RANGE(LAST_MATRIX),
 
     START_ENUM_RANGE(FIRST_MATRIX_FLOAT),
+    ExtremeRaysFloat,
     SuppHypsFloat,
     VerticesFloat,
     END_ENUM_RANGE(LAST_MATRIX_FLOAT),
@@ -92,6 +92,7 @@ enum Enum {
     WitnessNotIntegrallyClosed,
     GeneratorOfInterior,
     CoveringFace,
+    AxesScaling,
     END_ENUM_RANGE(LAST_VECTOR),
 
     // integer valued
@@ -161,6 +162,8 @@ enum Enum {
     UnimodularTriangulation,
     LatticePointTriangulation,
     AllGeneratorsTriangulation,
+    PlacingTriangulation,
+    PullingTriangulation,
     StanleyDec,
     InclusionExclusionData,
     IntegerHull,
@@ -168,10 +171,11 @@ enum Enum {
     ConeDecomposition,
     //
     Automorphisms,
-    AmbientAutomorphisms,
     CombinatorialAutomorphisms,
     RationalAutomorphisms,
     EuclideanAutomorphisms,
+    AmbientAutomorphisms,
+    InputAutomorphisms,
     //
     HilbertSeries,
     HilbertQuasiPolynomial,
@@ -179,9 +183,13 @@ enum Enum {
     EhrhartQuasiPolynomial,
     WeightedEhrhartSeries,
     WeightedEhrhartQuasiPolynomial,
+    //
     FaceLattice,
+    DualFaceLattice,
     FVector,
+    DualFVector,
     Incidence,
+    DualIncidence,
     Sublattice,
     //
     ClassGroup,
@@ -218,16 +226,31 @@ enum Enum {
     NoGradingDenom,
     GradingIsPositive,
     ExploitAutomsVectors,
-    ExploitAutomsMult,
+    ExploitIsosMult,
+    StrictIsoTypeCheck,
+    SignedDec,
+    NoSignedDec,
+    FixedPrecision,
+    DistributedComp,
+    NoPatching,
+    NoCoarseProjection,
     //
     Dynamic,
     Static,
     //
+    WritePreComp,
+    //
+    END_ENUM_RANGE(LAST_PROPERTY),
+    //
     // ONLY FOR INTERNAL CONTROL
     //
-    // ExplicitHilbertSeries,
+    START_ENUM_RANGE(FIRST_INTERNAL),
+    BasicTriangulation,
+    BasicStanleyDec,
     NakedDual,
     FullConeDynamic,
+    Generators,
+    PullingTriangulationInternal,
     //
     // ONLY FOR E§XTENDED TESTS
     //
@@ -240,7 +263,7 @@ enum Enum {
     TestLinearAlgebraGMP,
     TestSimplexParallel,
     TestLibNormaliz,
-    END_ENUM_RANGE(LAST_PROPERTY),
+    END_ENUM_RANGE(LAST_INTERNAL),
 
     EnumSize  // this has to be the last entry, to get the number of entries in the enum
 
@@ -261,7 +284,7 @@ class ConeProperties {
     ConeProperties(const std::bitset<ConeProperty::EnumSize>&);
 
     /* set properties */
-    ConeProperties& set(bool value = true); // set ALL to value;
+    ConeProperties& set(bool value = true);  // set ALL to value;
     ConeProperties& set(ConeProperty::Enum, bool value = true);
     ConeProperties& set(const std::string s, bool value = true);
     ConeProperties& set(ConeProperty::Enum, ConeProperty::Enum);
@@ -269,14 +292,14 @@ class ConeProperties {
     ConeProperties& set(const ConeProperties&);
 
     /* reset (=unset) properties */
-    ConeProperties& reset(); //reset ALL
+    ConeProperties& reset();  // reset ALL
     ConeProperties& reset(ConeProperty::Enum Property);
     ConeProperties& reset(const ConeProperties&);
     ConeProperties& reset_compute_options();
 
     // does not change *this
     ConeProperties intersection_with(const ConeProperties& ConeProps) const;
-    
+
     /* test which/how many properties are set */
     bool test(ConeProperty::Enum Property) const;
     bool any() const;
@@ -296,6 +319,7 @@ class ConeProperties {
 
     void check_conflicting_variants();
     void check_Q_permissible(bool after_implications);
+    void check_compatibility_with_polynomial_constraints(bool inhomogeneous);
     // void set_default_goals(bool inhomogeneous, bool numberfield);
 
     /* print it in a nice way */
@@ -312,13 +336,15 @@ const std::string& toString(ConeProperty::Enum);
 std::ostream& operator<<(std::ostream&, const ConeProperties&);
 OutputType::Enum output_type(ConeProperty::Enum);
 
-ConeProperties all_options(); // returns cps with the options set
-ConeProperties all_goals(); // returns cps with the options set
-ConeProperties all_full_cone_goals(bool renf); // returns the goals controlling compute_full_cone()
-ConeProperties all_goals_using_grading(bool inhomogeneous); // returns the goals which depend on grading
+ConeProperties all_options();                                // returns cps with the options set
+ConeProperties all_goals();                                  // returns cps with the options set
+ConeProperties all_full_cone_goals(bool renf);               // returns the goals controlling compute_full_cone()
+ConeProperties all_goals_using_grading(bool inhomogeneous);  // returns the goals which depend on grading
 ConeProperties only_homogeneous_props();
 ConeProperties only_inhomogeneous_props();
 ConeProperties treated_as_hom_props();
+ConeProperties all_automorphisms();
+ConeProperties all_triangulations();
 
 }  // namespace libnormaliz
 
