@@ -2,17 +2,13 @@
 #define LIBNORMALIZ_NMZ_VERSION_H
 
 #define NMZ_VERSION_MAJOR  3
-#define NMZ_VERSION_MINOR  8
-#define NMZ_VERSION_PATCH  10
-#define NMZ_VERSION        3.8.10
+#define NMZ_VERSION_MINOR  9
+#define NMZ_VERSION_PATCH  4
+#define NMZ_VERSION        3.9.4
 #define NMZ_RELEASE (NMZ_VERSION_MAJOR * 10000 + NMZ_VERSION_MINOR * 100 + NMZ_VERSION_PATCH)
 
 namespace libnormaliz {
-inline unsigned int getVersion()
-{
-    return NMZ_RELEASE;
-}
-
+unsigned int getVersion();
 } //end namespace libnormaliz
 
 #endif // NMZ_VERSION_H
